C/C++ Datatypes API
===================

.. autodoxygenfile:: datatypes.h
   :project: yggdrasil
	     
.. autodoxygenfile:: MetaschemaType.h
   :project: yggdrasil

.. autodoxygenfile:: ScalarMetaschemaType.h
   :project: yggdrasil
	     
.. autodoxygenfile:: JSONArrayMetaschemaType.h
   :project: yggdrasil
	     
.. autodoxygenfile:: JSONObjectMetaschemaType.h
   :project: yggdrasil
	     
.. autodoxygenfile:: AsciiTableMetaschemaType.h
   :project: yggdrasil
	     
.. autodoxygenfile:: PlyMetaschemaType.h
   :project: yggdrasil
	     
.. autodoxygenfile:: ObjMetaschemaType.h
   :project: yggdrasil
	     
.. autodoxygenfile:: DirectMetaschemaType.h
   :project: yggdrasil
